<?php
add_action("wp_ajax_dippsy_add_file", "dippsy_ajax_add_file");
add_action("wp_ajax_dippsy_delete_file", "dippsy_ajax_delete_file");
add_action("wp_ajax_dippsy_delete_product", "dippsy_ajax_delete_product");
add_action("wp_ajax_dippsy_check_images", "dippsy_check_images");
add_action("wp_ajax_dippsy_check_products", "dippsy_check_products");
add_action("wp_ajax_dippsy_send_ordered", "dippsy_send_test_ordered_mail");
add_action("wp_ajax_dippsy_send_changed", "dippsy_send_test_changed_mail");
add_action("wp_ajax_dippsy_send_completed", "dippsy_send_test_completed_mail");
add_action("wp_ajax_dippsy_resend_completed", "dippsy_resend_completed_mail");
add_action("wp_ajax_dippsy_change_order_status", "dippsy_change_order_status");
add_action("wp_ajax_dippsy_add_button", "dippsy_ajax_add_button");


function dippsy_ajax_add_file()
{
	if(!dippsy_check_admin_and_referrer('dippsy_add_file_nonce'))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("You don't have the permission to do that.", 'dippsy')));
		exit();
	}
	
	//is upload path writable
	if(!dippsy_check_products_folder())
    {
    	echo json_encode(array("status"=>"ERROR","message"=>__("Upload folder is not writable. Chmod it to (at least) 755.", 'dippsy')));
		exit();
    }
  	
    $dippsy_product_ID = absint($_POST['dippsy_product_id']);
    
	//is product id valid
	if(!dippsy_check_is_product($dippsy_product_ID))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Parent not a Dippsy product.", 'dippsy')));
		exit();
	}
	
	if(!(isset($_FILES["dippsy_file"])&& $_FILES['dippsy_file'] != ""))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("File not set.", 'dippsy')));
		exit();
	}

	if ($_FILES["dippsy_file"]['error'] != UPLOAD_ERR_OK)
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Error with uploaded file.", 'dippsy')));
		exit();
	}
	
	//dippsy_file
	$tmp_name = $_FILES["dippsy_file"]["tmp_name"];
	$name = sanitize_file_name($_FILES["dippsy_file"]["name"]);

	$price = dippsy_absolute_float($_POST['dippsy_file_price']);
	$description = sanitize_text_field($_POST['dippsy_file_description']);

	$uploaded = move_uploaded_file($tmp_name, UPLOAD_FILES_PATH.$name);

	if(!$uploaded)
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Could not save file. Maybe the folder isn't writable?", 'dippsy')));
		exit();	
	}
	
	$post = array(
		  'post_content' => $description,
		  'post_title' => $name,
			'post_type' => 'dippsy_file',
			'post_status' => 'publish',
			'comment_status' => 'closed',
	 		'ping_status' => 'closed', 
	 		'post_parent' => $dippsy_product_ID
	);

	$post_id = wp_insert_post($post);

	if($post_id == 0)
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Could not save file.", 'dippsy')));
		exit();
	}

	$thumbnail = dippsy_get_file_image($name,'thumb');
	
	add_post_meta($post_id, 'dippsy_file_name', $name, true);
	add_post_meta($post_id, 'dippsy_file_price', $price, true);
	add_post_meta($post_id, 'dippsy_file_thumbnail',$thumbnail, true);
	
	echo json_encode(array("status"=>"SUCCESS","message"=>__("File added succesfully!", 'dippsy'),"id" =>$post_id,"name" => $name ,"description"=>$description,"price"=>$price,"thubmnail"=>$thumbnail));
	exit();
}

function dippsy_ajax_delete_product()
{
	if(!dippsy_check_admin_and_referrer('dippsy_delete_product_nonce'))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("You don't have the permission to do that.", 'dippsy')));
		exit();
	}
	
	$product_id = absint($_POST['dippsy_product_id']);
    
	//is product id valid
	if(!dippsy_check_is_product($product_id))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Not a Dippsy product.", 'dippsy')));
		exit();
	}
	
	//do we need check?
	if(dippsy_delete_can_product($product_id))
	{
		if(dippsy_delete_product($product_id))
		{
			echo json_encode(array("status"=>"SUCCESS","message"=>__("Product deleted successfully!", 'dippsy')));
			exit();
		}
		else
		{
			echo json_encode(array("status"=>"ERROR","message"=>__("Could not delete product.", 'dippsy')));
			exit();
		}
	}
	else
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Cannot delete! Product has an order in progress.", 'dippsy')));
		exit();
	}
	
	exit();
}

function dippsy_ajax_delete_file()
{
	if(!dippsy_check_admin_and_referrer('dippsy_delete_file_nonce'))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("You don't have the permission to do that.", 'dippsy')));
		exit();
	}

	$product_id = absint($_POST['dippsy_product_id']);
    
	//is product id valid
	if(!dippsy_check_is_product($product_id))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("File parent not a Dippsy product.", 'dippsy')));
		exit();
	}
		
	$file_id = absint($_POST['dippsy_file_id']);

	//is file id valid
	if(!dippsy_check_is_file($file_id))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("File not a Dippsy file!", 'dippsy')));
		exit();
	}

	if(dippsy_delete_can_file($file_id))
	{
		if(dippsy_delete_file($file_id))
		{
			echo json_encode(array("status"=>"SUCCESS","message"=>__("File deleted successfully!", 'dippsy')));
			exit();
		}
		else
		{
			echo json_encode(array("status"=>"ERROR","message"=>__("Could not delete file.", 'dippsy')));
			exit();
		}	
	}
	else
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("File has an order in progress.", 'dippsy')));
		exit();
	}
	
	exit();
}

function dippsy_check_images()
{
	if(!dippsy_check_admin_and_referrer('dippsy_check_images_nonce'))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("You don't have the permission to do that.", 'dippsy')));
		exit();
	}

	if(!dippsy_check_images_folder())
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Images folder is NOT writable!", 'dippsy')));
		exit();
	}
	else
	{
		echo json_encode(array("status"=>"SUCCESS","message"=>__("Images folder IS writable!", 'dippsy')));
		exit();
	}

	exit();
}

function dippsy_check_products()
{
	if(!dippsy_check_admin_and_referrer('dippsy_check_products_nonce'))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("You don't have the permission to do that.", 'dippsy')));
		exit();
	}

	if(!dippsy_check_products_folder())
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Products folder is NOT writable!", 'dippsy')));
		exit();
	}
	else
	{
		echo json_encode(array("status"=>"SUCCESS","message"=>__("Products folder IS writable!", 'dippsy')));
		exit();
	}

	exit();
}

function dippsy_send_test_ordered_mail()
{
	if(!dippsy_check_admin_and_referrer('dippsy_send_ordered_nonce'))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("You don't have the permission to do that.", 'dippsy')));
		exit();
	}
	
	$blogname = get_option('blogname');
	
	$from= "MIME-Version: 1.0\n" .
        "From: [TEST EMAIL] ".get_option("dippsy_mail_from_field")." <".get_option("admin_email").">\n".
        "Content-Type: text/html; charset=\"" .
		get_option('blog_charset') . "\"\n";	
	$subject = get_option("dippsy_ordered_subject_field");
	
	$search = array('$first_name',
								'$last_name',
								'$txnid',
								'$file',
								'$blogname');

	$replace = array('[TEST Name]',
						'[TEST Surname]',
						'[TEST Transaction ID]',
						'[TEST Filename]',
						'[TEST Blogname]');

	$body = str_replace($search, $replace, get_option('dippsy_order_message'));

	if(wp_mail(get_option("admin_email"), $subject, $body, $from))
	{
		echo json_encode(array("status"=>"SUCCESS","message"=>__("Test 'Ordered' e-mail sent successfully!", 'dippsy')));
		exit();
	}
	else
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Test 'Ordered' e-mail sending failed!", 'dippsy')));
		exit();
	}
	
	exit();
}

function dippsy_send_test_changed_mail()
{
	if(!dippsy_check_admin_and_referrer('dippsy_send_changed_nonce'))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("You don't have the permission to do that.", 'dippsy')));
		exit();
	}

	$blogname = get_option('blogname');
	$from= "MIME-Version: 1.0\n" .
        "From: [TEST EMAIL] ".get_option("dippsy_mail_from_field")." <".get_option("admin_email").">\n".
        "Content-Type: text/html; charset=\"" .
		get_option('blog_charset') . "\"\n";	
	$subject = get_option("dippsy_changed_subject_field"); 
	
	$search = array('$first_name',
								'$last_name',
								'$txnid',
								'$file',
								'$status',
								'$shopmail',
								'$blogname');

	$replace = array('[TEST Name]',
						'[TEST Surname]',
						'[TEST Transaction ID]',
						'[TEST Filename]',
						'[TEST Status]',
					'[TEST Email]',
					'[TEST Shopname]');

	$body = str_replace($search, $replace, get_option('dippsy_changed_message'));

	if(wp_mail(get_option("admin_email"), $subject, $body, $from))
	{
		echo json_encode(array("status"=>"SUCCESS","message"=>__("Test 'Status Changed' e-mail sent successfully!", 'dippsy')));
		exit();
	}
	else
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Test 'Status Changed' e-mail sending failed!", 'dippsy')));
		exit();
	}
	
	exit();
}

function dippsy_send_test_completed_mail()
{
	if(!dippsy_check_admin_and_referrer('dippsy_send_completed_nonce'))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("You don't have the permission to do that.", 'dippsy')));
		exit();
	}

	$blogname = get_option('blogname');
	
	$from= "MIME-Version: 1.0\n" .
        "From: [TEST EMAIL] ".get_option("dippsy_mail_from_field")." <".get_option("admin_email").">\n".
        "Content-Type: text/html; charset=\"" .
		get_option('blog_charset') . "\"\n";	
	
	$subject = get_option("dippsy_completed_subject_field");
	$downloadlink = "<a href=\"www.google.com\">[TEST Download link]</a>";

	$search = array('$first_name',
								'$last_name',
								'$file',
								'$download',
								'$count',
								'$validity',
								'$blogname');

	$replace = array('[TEST Name]',
						'[TEST Surname]',
						'[TEST Filename]',
						'[TEST Download link]',
						'[TEST Download count]',
					'[TEST Validity]',
					'[TEST Shopname]');
	
	$replace = array(get_post_meta($transaction->ID,"dippsy_order_payer_name",true),
						get_post_meta($transaction->ID,"dippsy_order_payer_surname",true),
						get_post_meta($file->ID,"dippsy_file_name",true),
						$downloadlink,
						get_option('dippsy_downloads_count'),
						get_option('dippsy_download_validity'),
						$blogname);

	$body = str_replace($search, $replace, get_option('dippsy_completed_message'));

	if(wp_mail(get_option("admin_email"), $subject, $body, $from))
	{
		echo json_encode(array("status"=>"SUCCESS","message"=>__("Test 'Completed' e-mail sent successfully!", 'dippsy')));
		exit();
	}
	else
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Test 'Completed' e-mail sending failed!", 'dippsy')));
		exit();
	}
	
	exit();
}

function dippsy_resend_completed_mail()
{
	if(!dippsy_check_admin_and_referrer('dippsy_resend_completed_nonce'))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("You don't have the permission to do that.", 'dippsy')));
		exit();
	}

	//is order id valid
	$dippsy_order_ID = absint($_POST['dippsy_order_id']);

	//is product id valid
	if(!dippsy_check_is_order($dippsy_order_ID))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Not a valid Dippsy order!", 'dippsy')));
		exit();
	}
	
	if(get_post_meta($dippsy_order_ID,"dippsy_order_status",true) == "Completed")
	{
		if(dippsy_completed_mail($dippsy_order_ID))
		{
			echo json_encode(array("status"=>"SUCCESS","message"=>__("'Completed' e-mail re-sent successfully!", 'dippsy')));
			exit();
		}
		else
		{
			echo json_encode(array("status"=>"ERROR","message"=>__("'Completed' e-mail re-sending failed!", 'dippsy')));
			exit();
		}
	}
	else
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Order not yet completed!", 'dippsy')));
		exit();
	}
	
	exit();
}

/*
function dippsy_change_order_status()
{
	if(!check_ajax_referer('dippsy_change_order_status_nonce','dippsy_change_order_status_nonce',false))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Wrong referrer.", 'dippsy')));
		exit();
	}

	if(!current_user_can('manage_options'))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("You must be Administrator to use this function!", 'dippsy')));
		exit();
	}

	//is order id valid
	$dippsy_order = get_post($_POST['dippsy_order_id']);
	
	if(empty($dippsy_order) || $dippsy_order->post_type != 'dippsy_order')
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Not a valid Dippsy order!", 'dippsy')));
		exit();
	}
	
	
	
	exit();
}*/

function dippsy_ajax_add_button()
{
	if(!dippsy_check_admin_and_referrer('dippsy_add_button_nonce'))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("You don't have the permission to do that.", 'dippsy')));
		exit();
	}
	
	//is images path writable
	if(!dippsy_check_images_folder())
    {
    	echo json_encode(array("status"=>"ERROR","message"=>__("Images folder is not writable. Chmod it to (at least) 755.", 'dippsy')));
		exit();
    }
	
	if(!(isset($_FILES["dippsy_button"])&& $_FILES['dippsy_button'] != ""))
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Button not set.", 'dippsy')));
		exit();
	}

	if ($_FILES["dippsy_button"]['error'] != UPLOAD_ERR_OK)
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Error with uploaded button.", 'dippsy')));
		exit();
	}
	
	$filename = sanitize_file_name($_FILES["dippsy_button"]["name"]);
	$tmp_name = $_FILES["dippsy_button"]["tmp_name"];
	$valid = array('jpg','png','gif','bmp','tif');
	
	//chekc if file is image
	$info = wp_check_filetype_and_ext($tmp_name,$filename);
	
	if(!in_array(strtolower($info['ext']),$valid))
	{
		echo json_encode(array("status"=>"ERROR","message"=>$info['ext']));
		//echo json_encode(array("status"=>"ERROR","message"=>__("Not an image.", 'dippsy')));
		exit();
	}
	
	$uploaded = @move_uploaded_file($tmp_name, IMAGES_PATH."button.png");

	if(!$uploaded)
	{
		echo json_encode(array("status"=>"ERROR","message"=>__("Could not save button. Please, try later.", 'dippsy')));
		exit();	
	}
	
	echo json_encode(array("status"=>"SUCCESS","url"=>IMAGES_URL."button.png","message"=>__("Button added succesfully!", 'dippsy')));
	exit();
}
?>