<?php
add_action("save_post", "dippsy_updated_post", 10, 2);
add_action('admin_notices', 'dippsy_notices');

function dippsy_updated_post($post_id, $post = null)
{
	// verify this came from the our screen and with proper authorization,
	// because save_post can be triggered at other times
	/*
	 if ( !wp_verify_nonce( $_POST['myplugin_noncename'], plugin_basename(__FILE__) )) {
	 return $post_id;
	 }
	 */

	if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE )
	{
		return $post_id;
	}
	else
	{
		if ( defined('DOING_AJAX') && DOING_AJAX)
		{
			if ($post->post_type == "dippsy_order")
			{
				if(isset($_POST['dippsy_order_status_change']))
				{
					$change_to = $_POST['dippsy_order_status_change'];
					$current = get_post_meta($post_id,"dippsy_order_status",true);
					$failed = array("Pending","Cancelled","Failed","Denied","Expired","Partially refunded","Refunded","Reversed","Voided");

					if($current !== $change_to)
					{
						if($change_to == "Completed")
						{
							$file = dippsy_get_file_from_order($post_id);
							$file_id = $file->ID;
							$payer_email = get_post_meta($post_id,"dippsy_order_payer_mail",true);
							$hash = sha1(uniqid(mt_rand(), true).$file_id.$payer_email);
							$date=strftime('%Y-%m-%d %H:%M:%S',mktime());
								
							update_post_meta($post_id,"dippsy_order_hash",$hash);
							update_post_meta($post_id,"dippsy_order_status","Completed");
							update_post_meta($post_id,"dippsy_order_cleared_date",$date);
							update_post_meta($post_id,"dippsy_order_download_count",0,true);
	
							dippsy_completed_mail($post_id);
						}
						else
						if(in_array($change_to,$failed))
						{
							update_post_meta($post_id,"dippsy_order_status",$change_to);
						}
					}
				}
			}
		}
		//fixes quick edit update from 'edit posts' button they are blank
		else
		{
			if ($post->post_type == "dippsy_product")
		 	{
		 		if(isset($_POST['dippsy_files']))
		 		{
		 			foreach ($_POST['dippsy_files'] as $file_id => $variables)
		 			{
		 				$post = array(
		 						'ID' => $file_id,
			  					'post_content' => sanitize_text_field($variables['description']),
		 				);
	
		 				$post_id = wp_update_post($post);
	
		 				update_post_meta($file_id, "dippsy_file_price", dippsy_absolute_float($variables['price']));
		 			}
		 		}
		 	}
		}
	}

	return $post_id;	
}

function dippsy_get_file_image($filename, $type)
{
	$ext = explode('.',$filename);
	$extension = array_pop($ext);

	switch ($type) {
		case 'thumb':
			$end = "_thumbnail.png";
		break;
		case 'image':
			$end = ".png";
		break;
		default:
			;
		break;
	}
	
	if(file_exists(IMAGES_PATH.$extension.$end))
	{
		return IMAGES_URL.$extension.$end;
	}
	else
	{
		//create new format image (large AND thumbnail!)
		
		//large
		$img = imagecreatefrompng(IMAGES_PATH."blank.png");
		//imagealphablending($img, false);
		imagesavealpha($img, true);
			
		//thumbnail
		$thumb = imagecreatetruecolor(64, 64);
		imagealphablending($thumb, false);
		imagesavealpha($thumb, true);
			
		$font = IMAGES_PATH.'ariblk.ttf';
		$text = strtoupper($extension);

		// First we create maximum bounding box for the first text
		$size = 0;

		for ($index = 0; $index < 20; $index++)
		{
			$bbox = imagettfbbox($index, 0, $font, $text);
				
			if((max($bbox[1],$bbox[3]) - min($bbox[5],$bbox[7])) > 27 || (min($bbox[2],$bbox[4]) - max($bbox[0],$bbox[6])) > 76)
			{
				break;
			}
			else
			{
				$size = $index;
			}
		}

		$text_h = (max($bbox[1],$bbox[3]) - min($bbox[5],$bbox[7]))/2;
		$text_w = (min($bbox[2],$bbox[4]) - max($bbox[0],$bbox[6]))/2;

		$rect_h_m = 33 + 27/2;
		$rect_w_m = 13 + 76/2;

		$white = imagecolorallocatealpha($img, 255, 255, 255,0);
		imagettftext($img,$size,0,$rect_w_m-$text_w,$rect_h_m+$text_h,$white,$font,$text);

		// Resize
		imagecopyresampled($thumb, $img, 0, 0, 0, 0, 64, 64, 100, 100);
			
		//save both
		imagepng($img,IMAGES_PATH.$extension.".png");
		imagepng($thumb,IMAGES_PATH.$extension."_thumbnail.png");

		imagedestroy($img);
		imagedestroy($thumb);
		
		return IMAGES_URL.$extension.$end;
	}
}

function dippsy_notices()
{	
 	if(!file_exists(UPLOAD_FILES_PATH.".htaccess"))
	{
		@file_put_contents(UPLOAD_FILES_PATH.".htaccess","Order deny,allow\nDeny from all\nOptions -Indexes\n");
	}
	
	if(!dippsy_check_settings())
	{
		echo '<div class="updated fade below-h2" id="message"><p>'.__("Some Dippsy settings are not set. Please set them at the <a href='admin.php?page=dippsy-settings'>Dippsy Settings admin page</a>. If this is your first time you see this message and/or you haven't completed the installation, see the <a href='admin.php?page=dippsy-settings#tabs-6'>Completing installation tab under the same page</a>", 'dippsy').'</a>.</p></div>';
	}
}

function dippsy_check_images_folder() 
{
	if(!is_dir(IMAGES_PATH) || @file_put_contents(IMAGES_PATH."test.tmp", "TEST") === false )
	{
		return false;
	}
	else
	{
		@unlink($folder."test.tmp");
		return true;
	}
}

function dippsy_check_products_folder() 
{
	if( !is_dir(UPLOAD_FILES_PATH) || @file_put_contents(UPLOAD_FILES_PATH."test.tmp", "TEST") === false )
    {
		return false;  	
    }
    else
    {
    	@unlink(UPLOAD_FILES_PATH."test.tmp");
		return true;
    }

}

function dippsy_check_settings() 
{
	if(get_option('dippsy_currency_code') == "NONE" ||
	get_option('dippsy_paypal_email') == "" ||
	get_option('dippsy_tax') == "" ||
	get_option('dippsy_mail_from_field')== "" ||
	get_option('dippsy_ordered_subject_field')== "" ||
	get_option('dippsy_changed_subject_field')== "" ||
	get_option('dippsy_completed_subject_field')== "" ||
	get_option('dippsy_store_page') == "" ||
	get_option('dippsy_complete_page') == "" ||
	get_option('dippsy_cancel_page') == "" ||
	get_option('dippsy_complete_message') == "" ||
	get_option('dippsy_changed_message') == "" ||
	get_option('dippsy_order_message') == "" ||
	get_option('dippsy_completed_message') == "" ||
	get_option('dippsy_downloads_count') == "" ||
	get_option('dippsy_download_validity') == "")
	{
		return false;
	}
	else
	{
		return true;
	}
}

function dippsy_check_is_file($id) 
{
	$dippsy_file = get_post($id);
	
	if(empty($dippsy_file) || $dippsy_file->post_type != 'dippsy_file')
	{
		return false;
	}
	else
		return true;
}

function dippsy_check_is_product($id) 
{
	$dippsy_product = get_post($id);
	
	if(empty($dippsy_product) || $dippsy_product->post_type != 'dippsy_product')
	{
		return false;
	}
	else
		return true;
}

function dippsy_check_is_order($id) 
{
	$dippsy_order = get_post($id);
	
	if(empty($dippsy_order) || $dippsy_order->post_type != 'dippsy_order')
	{
		return false;
	}
	else
		return true;
}

function dippsy_absolute_float($value) 
{
	return abs(floatval($value));
}

function dippsy_json_error($message) 
{
	echo json_encode(array("status"=>"ERROR","message"=>$message));	
}

function dippsy_json_success($message) 
{
	$out = array("status"=>"SUCCESS");
	$out = array_merge($out,$message);
	echo json_encode($out);	
}

function dippsy_check_admin_and_referrer($ref) 
{
	if(!check_ajax_referer($ref,$ref,false) || !current_user_can('manage_options') || !is_admin())
	{
		return false;
	}
	else
		return true;
}
?>