<?php

/*
 * Shortcode hooks
 */

add_shortcode('dippsy_store', 'dippsy_store_shortcode');
add_shortcode('dippsy_complete', 'dippsy_complete_order_shortcode');
add_shortcode('dippsy_cancel', 'dippsy_cancel_order_shortcode');

function dippsy_store_shortcode($atts)
{	
	$output = '';
	
	if(!dippsy_check_settings())
	{
		$output .= __("Oops. Some settings needed for store functionality have not been set. Please set them
		in <a href='admin.php?page=dippsy-settings'>Dippsy shop Settings</a> admin page", 'dippsy').
		"<br />";
	}
	else
	{
		add_action('wp_footer', 'dippsy_store_css');
		
		extract(shortcode_atts(array('id' => null), $atts));
		
		if(!is_null($id))
		{
			$product_ids = explode(',',$id);
			$products = get_posts( array('post_type'=>'dippsy_product','post_status' => 'publish','nopaging' => true,'post__in'=>$product_ids));
		}	
		else
		{		
			$products = dippsy_get_products_list();
		}
		
		if($products)
		{
			foreach ($products as $product)
			{
				$title = $product->post_title;
				$description = $product->post_content;
				
				$output .= '<div class="product">';
				$output .= "<a name='".$product->ID."'><h2>$title</h2></a>";
					
				if(	current_theme_supports('post-thumbnails') && has_post_thumbnail($product->ID))
				{
					$output .= get_the_post_thumbnail($product->ID, 'large');
				}
				
				$output .= "<p>$description</p>";
					
				$files =  dippsy_get_product_files($product->ID);

				if($files)
				{
					$output .= "<strong>".__("Buyable formats", 'dippsy').":</strong>";

					foreach ($files as $file)
					{
						$name = get_post_meta($file->ID,"dippsy_file_name",true);
						$number = $file->ID;
						$currency = get_option('dippsy_currency_code');
						$mail = get_option('dippsy_paypal_email');
						$ipn_url = site_url().'/index.php';
						$desc = $file->post_content;
						$price_show = round(get_post_meta($file->ID,"dippsy_file_price",true),2);
						$tax = round((get_option('dippsy_tax')/100)*$price_show,2);
						
						$price = sprintf("%01.2f", $price_show-$tax);
						
						if(get_option('dippsy_use_sandbox'))
						{
							$url = "https://www.sandbox.paypal.com/cgi-bin/webscr";
						}
						else
						{
							$url = "https://www.paypal.com/cgi-bin/webscr";
						}
						
						$output .= "
						<form name='$number' action='$url' method='post' target='_blank'>
							<input type='hidden' name='cmd' value='_xclick' />
							<input type='hidden' name='business' value='$mail' />
							<input type='hidden' name='item_name' value='$name' />
							<input type='hidden' name='item_number' value='$number' />
							<input type='hidden' name='amount' value='$price' />
							<input type='hidden' name='tax' value='$tax' />
							<input type='hidden' name='no_shipping' value='1' />
							<input type='hidden' name='no_note' value='1' />
							<input type='hidden' name='currency_code' value='$currency' />
							<input type='hidden' name='custom' value='dippsy_ipn' />
							<input type='hidden' name='notify_url' value='$ipn_url' />
							<input type='hidden' name='return' value='".COMPLETE_URL."' />
							<input type='hidden' name='cancel_return' value='".CANCEL_URL."' />
										
							<div class='download'>
								<img alt='Buy format' src='". dippsy_get_file_image($name,'image')."' /> 
								<br />
								<div class='product_description'>$desc</div> 
								<strong>$price_show $currency</strong>
								<div class='buy'>";
						
						if(get_option('dippsy_use_custom_button'))
						{
							$output .= "<input class='custom' type='image' src='".plugins_url("images/button.png",__FILE__)."' />";
						}
						else
						{
							$output .= "<input class='default' type='submit' name='Submit' value='".__("Buy now", 'dippsy')."' />";
						}
						
						$output .= "</div>
							</div>
						</form>";
					}
				}
				else
				{
					$output .= '<div class="download"><strong>'.__("Coming soon!", 'dippsy').'</strong></div>';
				}

				$output .=  "</div>";
			}
		}
		else
		{
			$output .= __("Coming soon!", 'dippsy')."<br />";
		}
	}
	
	return $output;
}

function dippsy_complete_order_shortcode($atts)
{
	return get_option('dippsy_complete_message');
}

function dippsy_cancel_order_shortcode($atts)
{
	return get_option('dippsy_cancel_message');;
}

?>